// Set the dimensions of the canvas / graph
var margin = { top: 30, right: 20, bottom: 70, left: 70 },
  width = 960 - margin.left - margin.right,
  height = 500 - margin.top - margin.bottom;

// Parse the date / time
var parseDate = d3.timeParse('%Y-%m-%d');

// Set the ranges
var x = d3.scaleTime().range([0, width]);
var y = d3.scaleLinear().range([height, 0]);

// Define the line
var valueline = d3
  .line()
  .x(function (d) {
    return x(d.Date);
  })
  .y(function (d) {
    return y(d.Close);
  })
  .curve(d3.curveMonotoneX); // Smoother curve

// Adds the svg canvas
var svg = d3
  .select('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

// Get the data
d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/1c43c8e7888c5df109d46a4403734ba6/raw/d86330c694f6cf146073b47d448c19c57ed265f9/dominos.csv',
).then(function (data) {
  // Format the data
  data.forEach(function (d) {
    d.Date = parseDate(d.Date);
    d.Close = +d.Close;
  });

  // Scale the range of the data
  x.domain(
    d3.extent(data, function (d) {
      return d.Date;
    }),
  );
  y.domain([
    0,
    d3.max(data, function (d) {
      return d.Close;
    }),
  ]);

  // Add the valueline path.
  svg
    .append('path')
    .data([data])
    .attr('class', 'line')
    .attr('d', valueline);

  // Add the X Axis
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x).tickFormat(d3.timeFormat('%Y')))
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', width / 2)
    .attr('y', 40)
    .attr('fill', '#000')
    .text('Year');

  // Add the Y Axis
  svg
    .append('g')
    .call(d3.axisLeft(y))
    .append('text')
    .attr('class', 'axis-label')
    .attr('transform', 'rotate(-90)')
    .attr('y', -60)
    .attr('x', -height / 2)
    .attr('dy', '1em')
    .attr('fill', '#000')
    .text('Stock Price');

  // Add gridlines
  svg
    .append('g')
    .attr('class', 'grid')
    .attr('transform', 'translate(0,' + height + ')')
    .call(
      d3.axisBottom(x).tickSize(-height).tickFormat(''),
    );

  svg
    .append('g')
    .attr('class', 'grid')
    .call(d3.axisLeft(y).tickSize(-width).tickFormat(''));
});
